pub struct TelemetryLayer(/* private fields */);Expand description
Layer that handles the logs for telemetries.
Implementations
Sourceimpl TelemetryLayer
impl TelemetryLayer
Sourcepub fn new(
buffer_size: Option<usize>,
telemetry_external_transport: Option<ExtTransport>,
) -> Result<(Self, TelemetryWorker)>
pub fn new( buffer_size: Option<usize>, telemetry_external_transport: Option<ExtTransport>, ) -> Result<(Self, TelemetryWorker)>
Create a new TelemetryLayer and TelemetryWorker.
The buffer_size defaults to 16.
The ExtTransport is used in WASM contexts where we need some binding between the
networking provided by the operating system or environment and libp2p.
Important: Each individual call to
writecorresponds to one message. There is no internal buffering going on. In the context of WebSockets, eachwritemust be one individual WebSockets frame.